@@ -56,9 +56,11 @@ SELECT ?concat ?concatLength WHERE {
 
         # Instantiate FastAPI
         super().__init__(
+            *args,
             title=title,
             description=description,
             version=version,
+            **kwargs,
         )
 
         # Save custom function in custom evaluation dictionary
@@ -66,7 +68,7 @@ SELECT ?concat ?concatLength WHERE {
         if custom_eval:
             rdflib.plugins.sparql.CUSTOM_EVALS["evalCustomFunctions"] = custom_eval
         else:
-            rdflib.plugins.sparql.CUSTOM_EVALS["evalCustomFunctions"] = self.evalCustomFunctions
+            rdflib.plugins.sparql.CUSTOM_EVALS["evalCustomFunctions"] = self.eval_custom_functions
 
         if cors_enabled:
             self.add_middleware(
@@ -136,7 +138,7 @@ SELECT ?concat ?concatLength WHERE {
                 service_graph.parse(data=service_description_ttl, format="ttl")
 
                 # Add custom functions URI to the service description
-                for custom_function_uri in self.functions.keys():
+                for custom_function_uri in self.functions:
                     service_graph.add(
                         (
                             URIRef(custom_function_uri),
@@ -170,9 +172,13 @@ SELECT ?concat ?concatLength WHERE {
             # tq = algebraTranslateQuery(parsed_query)
             # pprintAlgebra(tq)
 
+            graph_ns = {}
+            for prefix, ns_uri in self.graph.namespaces():
+                graph_ns[prefix] = ns_uri
+
             try:
                 # Query the graph with the custom functions loaded
-                parsed_query = prepareQuery(query)
+                parsed_query = prepareQuery(query, initNs=graph_ns)
                 query_operation = re.sub(r"(\w)([A-Z])", r"\1 \2", parsed_query.algebra.name)
             except Exception as e:
                 logging.error("Error parsing the SPARQL query: " + str(e))
@@ -190,7 +196,7 @@ SELECT ?concat ?concatLength WHERE {
             #         return JSONResponse(status_code=403, content={"message": "Wrong API KEY."})
 
             try:
-                query_results = self.graph.query(query)
+                query_results = self.graph.query(query, initNs=graph_ns)
             except Exception as e:
                 logging.error("Error executing the SPARQL query on the RDFLib Graph: " + str(e))
                 return JSONResponse(
@@ -273,8 +279,9 @@ SELECT ?concat ?concatLength WHERE {
         @self.get("/", include_in_schema=False)
         async def serve_yasgui() -> Response:
             """Serve YASGUI interface"""
-            html_str = open(pkg_resources.resource_filename("rdflib_endpoint", "yasgui.html")).read()
-            html_str = html_str.replace('$EXAMPLE_QUERY', self.example_query)
+            with open(pkg_resources.resource_filename("rdflib_endpoint", "yasgui.html")) as f:
+                html_str = f.read()
+            html_str = html_str.replace("$EXAMPLE_QUERY", self.example_query)
             return Response(content=html_str, media_type="text/html")
 
         # Service description returned when no query provided
@@ -304,7 +311,7 @@ SELECT ?concat ?concatLength WHERE {
             description=self.description.replace("\n", ""),
         )
 
-    def evalCustomFunctions(self, ctx: QueryContext, part: CompValue) -> List[Any]:
+    def eval_custom_functions(self, ctx: QueryContext, part: CompValue) -> List[Any]:
         """Retrieve variables from a SPARQL-query, then execute registered SPARQL functions
         The results are then stored in Literal objects and added to the query results.
 
