@@ -15,7 +15,7 @@ def server(scope="module"):
         target=run_serve,
         args=(
             [pkg_resources.resource_filename("tests", "resources/test.nq")],
-            "0.0.0.0",
+            "localhost",
             8000,
         ),
         daemon=True,
@@ -28,8 +28,9 @@ def server(scope="module"):
 
 def test_query_serve(server):
     resp = requests.get(
-        "http://0.0.0.0:8000/sparql?query=" + select_all_query,
+        "http://localhost:8000/sparql?query=" + select_all_query,
         headers={"accept": "application/json"},
+        timeout=600,
     )
     assert len(resp.json()["results"]["bindings"]) > 0
 
